@@ -1,5 +1,5 @@
-# coding=utf-8
-# Copyright 2022 HuggingFace Inc.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,7 @@ import paddle
 
 from paddlenlp.transformers import CLIPTextConfig, CLIPTextModel
 from ppdiffusers import DDIMScheduler, LDMPipeline, UNet2DModel, VQModel
-from ppdiffusers.utils.testing_utils import slow
+from ppdiffusers.utils.testing_utils import require_paddle, slow
 
 
 class LDMPipelineFastTests(unittest.TestCase):
@@ -54,79 +54,52 @@ class LDMPipelineFastTests(unittest.TestCase):
     @property
     def dummy_text_encoder(self):
         paddle.seed(0)
-        config = dict(
-            text_embed_dim=32,
-            text_heads=4,
-            text_layers=5,
+        config = CLIPTextConfig(
+            bos_token_id=0,
+            eos_token_id=2,
+            hidden_size=32,
+            intermediate_size=37,
+            layer_norm_eps=1e-05,
+            num_attention_heads=4,
+            num_hidden_layers=5,
+            pad_token_id=1,
             vocab_size=1000,
         )
-        config = CLIPTextConfig.from_dict(config)
-        model = CLIPTextModel(config)
-        model.eval()
-        return model
+        return CLIPTextModel(config).eval()
 
     def test_inference_uncond(self):
         unet = self.dummy_uncond_unet
         scheduler = DDIMScheduler()
         vae = self.dummy_vq_model
-
         ldm = LDMPipeline(unet=unet, vqvae=vae, scheduler=scheduler)
         ldm.set_progress_bar_config(disable=None)
-
         generator = paddle.Generator().manual_seed(0)
-
         image = ldm(generator=generator, num_inference_steps=2, output_type="numpy").images
-
         generator = paddle.Generator().manual_seed(0)
-
         image_from_tuple = ldm(generator=generator, num_inference_steps=2, output_type="numpy", return_dict=False)[0]
-
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
-
         assert image.shape == (1, 64, 64, 3)
         expected_slice = np.array(
-            [
-                0.8270485401153564,
-                1.0,
-                0.6244686841964722,
-                0.772940456867218,
-                1.0,
-                0.7307173609733582,
-                0.6108742356300354,
-                0.9107264280319214,
-                0.7249622344970703,
-            ]
+            [0.827049, 1.0, 0.6244688, 0.7729403, 1.0, 0.73071766, 0.6108738, 0.9107263, 0.7249622]
         )
-
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 1e-2
+        tolerance = 0.01
+        assert np.abs(image_slice.flatten() - expected_slice).max() < tolerance
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < tolerance
 
 
 @slow
+@require_paddle
 class LDMPipelineIntegrationTests(unittest.TestCase):
     def test_inference_uncond(self):
         ldm = LDMPipeline.from_pretrained("CompVis/ldm-celebahq-256")
         ldm.set_progress_bar_config(disable=None)
-
         generator = paddle.Generator().manual_seed(0)
-
         image = ldm(generator=generator, num_inference_steps=5, output_type="numpy").images
-
         image_slice = image[0, -3:, -3:, -1]
-
         assert image.shape == (1, 256, 256, 3)
         expected_slice = np.array(
-            [
-                0.5980286598205566,
-                0.6169854402542114,
-                0.6275357007980347,
-                0.6128235459327698,
-                0.6096121668815613,
-                0.6172620058059692,
-                0.6060792207717896,
-                0.6026193499565125,
-                0.6129077672958374,
-            ]
+            [0.59802866, 0.61698544, 0.62753576, 0.6128236, 0.60961217, 0.617262, 0.6060791, 0.60261935, 0.6129079]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
+        tolerance = 0.01
+        assert np.abs(image_slice.flatten() - expected_slice).max() < tolerance
