@@ -1,5 +1,5 @@
-# coding=utf-8
-# Copyright 2022 HuggingFace Inc.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -33,19 +33,12 @@ from ppdiffusers import (
     UNet2DModel,
     VQModel,
 )
-from ppdiffusers.utils import (
-    TEST_DOWNLOAD_SERVER,
-    floats_tensor,
-    load_image,
-    load_numpy,
-    nightly,
-    slow,
-)
+from ppdiffusers.utils import floats_tensor, load_image, nightly, slow
+from ppdiffusers.utils.testing_utils import load_numpy, require_paddle_gpu
 
 
 class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
@@ -54,8 +47,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
     def dummy_image(self):
         batch_size = 1
         num_channels = 3
-        sizes = (32, 32)
-
+        sizes = 32, 32
         image = floats_tensor((batch_size, num_channels) + sizes, rng=random.Random(0))
         return image
 
@@ -132,25 +124,28 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
     @property
     def dummy_text_encoder(self):
         paddle.seed(0)
-        config = dict(
-            text_embed_dim=32,
-            text_heads=4,
-            text_layers=5,
+        config = CLIPTextConfig(
+            bos_token_id=0,
+            eos_token_id=2,
+            hidden_size=32,
+            intermediate_size=37,
+            layer_norm_eps=1e-05,
+            num_attention_heads=4,
+            num_hidden_layers=5,
+            pad_token_id=1,
             vocab_size=1000,
         )
-        config = CLIPTextConfig.from_dict(config)
-        model = CLIPTextModel(config)
-        model.eval()
-        return model
+        return CLIPTextModel(config).eval()
 
     @property
     def dummy_extractor(self):
         def extract(*args, **kwargs):
             class Out:
                 def __init__(self):
-                    self.pixel_values = paddle.ones([0])
+                    self.pixel_values = paddle.ones(shape=[0])
 
                 def to(self, device):
+                    self.pixel_values
                     return self
 
             return Out()
@@ -163,12 +158,9 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-
-        image_dummy = self.dummy_image.transpose([0, 2, 3, 1])[0]
-        init_image = Image.fromarray(np.uint8(image_dummy)).convert("RGB")
-        mask_image = Image.fromarray(np.uint8(image_dummy + 4)).convert("RGB").resize((32, 32))
-
-        # make sure here that pndm scheduler skips prk
+        image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
+        init_image = Image.fromarray(np.uint8(image)).convert("RGB")
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((32, 32))
         sd_pipe = StableDiffusionInpaintPipelineLegacy(
             unet=unet,
             scheduler=scheduler,
@@ -179,7 +171,6 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             feature_extractor=self.dummy_extractor,
         )
         sd_pipe.set_progress_bar_config(disable=None)
-
         prompt = "A painting of a squirrel eating a burger"
         generator = paddle.Generator().manual_seed(0)
         output = sd_pipe(
@@ -191,9 +182,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             image=init_image,
             mask_image=mask_image,
         )
-
         image = output.images
-
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = sd_pipe(
             [prompt],
@@ -205,26 +194,14 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             mask_image=mask_image,
             return_dict=False,
         )[0]
-
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
-
         assert image.shape == (1, 32, 32, 3)
         expected_slice = np.array(
-            [
-                0.0,
-                0.40522676706314087,
-                0.22000649571418762,
-                0.3371007442474365,
-                0.6130789518356323,
-                0.5699742436408997,
-                0.4295768141746521,
-                0.6762629747390747,
-                0.49702852964401245,
-            ]
+            [0.0, 0.42294562, 0.31831095, 0.11458772, 0.57409716, 0.6021224, 0.3139254, 0.6612497, 0.51271075]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_inpaint_legacy_negative_prompt(self):
         unet = self.dummy_cond_unet
@@ -232,12 +209,9 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-
-        image_dummy = self.dummy_image.transpose([0, 2, 3, 1])[0]
-        init_image = Image.fromarray(np.uint8(image_dummy)).convert("RGB")
-        mask_image = Image.fromarray(np.uint8(image_dummy + 4)).convert("RGB").resize((32, 32))
-
-        # make sure here that pndm scheduler skips prk
+        image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
+        init_image = Image.fromarray(np.uint8(image)).convert("RGB")
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((32, 32))
         sd_pipe = StableDiffusionInpaintPipelineLegacy(
             unet=unet,
             scheduler=scheduler,
@@ -248,7 +222,6 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             feature_extractor=self.dummy_extractor,
         )
         sd_pipe.set_progress_bar_config(disable=None)
-
         prompt = "A painting of a squirrel eating a burger"
         negative_prompt = "french fries"
         generator = paddle.Generator().manual_seed(0)
@@ -262,25 +235,13 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             image=init_image,
             mask_image=mask_image,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
-
         assert image.shape == (1, 32, 32, 3)
         expected_slice = np.array(
-            [
-                0.0,
-                0.41603270173072815,
-                0.25802189111709595,
-                0.2814731001853943,
-                0.5799428224563599,
-                0.5783349275588989,
-                0.38746166229248047,
-                0.6701520681381226,
-                0.5042654275894165,
-            ]
+            [0.0, 0.42320636, 0.3191024, 0.11486277, 0.5742749, 0.6025071, 0.31415784, 0.66176593, 0.5128486]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_inpaint_legacy_num_images_per_prompt(self):
         unet = self.dummy_cond_unet
@@ -288,12 +249,9 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-
-        image_dummy = self.dummy_image.transpose([0, 2, 3, 1])[0]
-        init_image = Image.fromarray(np.uint8(image_dummy)).convert("RGB")
-        mask_image = Image.fromarray(np.uint8(image_dummy + 4)).convert("RGB").resize((32, 32))
-
-        # make sure here that pndm scheduler skips prk
+        image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
+        init_image = Image.fromarray(np.uint8(image)).convert("RGB")
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((32, 32))
         sd_pipe = StableDiffusionInpaintPipelineLegacy(
             unet=unet,
             scheduler=scheduler,
@@ -304,33 +262,16 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             feature_extractor=self.dummy_extractor,
         )
         sd_pipe.set_progress_bar_config(disable=None)
-
         prompt = "A painting of a squirrel eating a burger"
-
-        # test num_images_per_prompt=1 (default)
         images = sd_pipe(
-            prompt,
-            num_inference_steps=2,
-            output_type="np",
-            image=init_image,
-            mask_image=mask_image,
+            prompt, num_inference_steps=2, output_type="np", image=init_image, mask_image=mask_image
         ).images
-
         assert images.shape == (1, 32, 32, 3)
-
-        # test num_images_per_prompt=1 (default) for batch of prompts
         batch_size = 2
         images = sd_pipe(
-            [prompt] * batch_size,
-            num_inference_steps=2,
-            output_type="np",
-            image=init_image,
-            mask_image=mask_image,
+            [prompt] * batch_size, num_inference_steps=2, output_type="np", image=init_image, mask_image=mask_image
         ).images
-
         assert images.shape == (batch_size, 32, 32, 3)
-
-        # test num_images_per_prompt for single prompt
         num_images_per_prompt = 2
         images = sd_pipe(
             prompt,
@@ -340,10 +281,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             mask_image=mask_image,
             num_images_per_prompt=num_images_per_prompt,
         ).images
-
         assert images.shape == (num_images_per_prompt, 32, 32, 3)
-
-        # test num_images_per_prompt for batch of prompts
         batch_size = 2
         images = sd_pipe(
             [prompt] * batch_size,
@@ -353,22 +291,25 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             mask_image=mask_image,
             num_images_per_prompt=num_images_per_prompt,
         ).images
-
         assert images.shape == (batch_size * num_images_per_prompt, 32, 32, 3)
 
 
 @slow
+@require_paddle_gpu
 class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
 
-    def get_inputs(self, dtype=paddle.float32, seed=0):
+    def get_inputs(self, dtype="float32", seed=0):
         generator = paddle.Generator().manual_seed(seed)
-        init_image = load_image(f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint/input_bench_image.png")
-        mask_image = load_image(f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint/input_bench_mask.png")
+        init_image = load_image(
+            "https://huggingface.co/datasets/diffusers/test-arrays/resolve/main/stable_diffusion_inpaint/input_bench_image.png"
+        )
+        mask_image = load_image(
+            "https://huggingface.co/datasets/diffusers/test-arrays/resolve/main/stable_diffusion_inpaint/input_bench_mask.png"
+        )
         inputs = {
             "prompt": "A red cat sitting on a park bench",
             "image": init_image,
@@ -387,14 +328,14 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
         )
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
-
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
-
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.27200, 0.29103, 0.34405, 0.21418, 0.26317, 0.34281, 0.18033, 0.24911, 0.32028])
-        assert np.abs(expected_slice - image_slice).max() < 1e-4
+        expected_slice = np.array(
+            [0.27226633, 0.29068208, 0.3450312, 0.21444553, 0.26328486, 0.34392387, 0.18026042, 0.24961185, 0.3214044]
+        )
+        assert np.abs(expected_slice - image_slice).max() < 0.0001
 
     def test_stable_diffusion_inpaint_legacy_k_lms(self):
         pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
@@ -403,14 +344,14 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
         pipe.scheduler = LMSDiscreteScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
-
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
-
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.29014, 0.28882, 0.32835, 0.26502, 0.28182, 0.31162, 0.29297, 0.29534, 0.28214])
-        assert np.abs(expected_slice - image_slice).max() < 1e-4
+        expected_slice = np.array(
+            [0.29036117, 0.28907132, 0.32839334, 0.26510137, 0.2820784, 0.31148806, 0.29358387, 0.29515788, 0.28257304]
+        )
+        assert np.abs(expected_slice - image_slice).max() < 0.0001
 
     def test_stable_diffusion_inpaint_legacy_intermediate_state(self):
         number_of_steps = 0
@@ -423,65 +364,43 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array(
-                    [
-                        -0.10290834307670593,
-                        1.41594660282135,
-                        -0.021856456995010376,
-                        -0.5102450251579285,
-                        -0.591240644454956,
-                        0.195754736661911,
-                        0.7505455017089844,
-                        0.3472331464290619,
-                        -1.3563168048858643,
-                    ]
-                )
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 1e-3
+                expected_slice = np.array([-0.103, 1.415, -0.02197, -0.5103, -0.5903, 0.1953, 0.75, 0.3477, -1.356])
+                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.001
             elif step == 2:
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array(
-                    [
-                        0.47839266061782837,
-                        1.1574846506118774,
-                        0.6261610984802246,
-                        0.2289661169052124,
-                        0.25498080253601074,
-                        -0.14365366101264954,
-                        0.7087358832359314,
-                        -0.1603042483329773,
-                        -0.5652803778648376,
-                    ]
-                )
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 1e-3
+                expected_slice = np.array([0.4802, 1.154, 0.628, 0.2322, 0.2593, -0.1455, 0.7075, -0.1617, -0.5615])
+                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.001
 
         callback_fn.has_been_called = False
-
         pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
-            "CompVis/stable-diffusion-v1-4",
-            safety_checker=None,
+            "CompVis/stable-diffusion-v1-4", safety_checker=None, paddle_dtype=paddle.float16
         )
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
-
-        inputs = self.get_inputs()
+        inputs = self.get_inputs(dtype="float16")
         pipe(**inputs, callback=callback_fn, callback_steps=1)
         assert callback_fn.has_been_called
         assert number_of_steps == 2
 
 
 @nightly
+@require_paddle_gpu
 class StableDiffusionInpaintLegacyPipelineNightlyTests(unittest.TestCase):
     def tearDown(self):
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
 
-    def get_inputs(self, dtype=paddle.float32, seed=0):
+    def get_inputs(self, dtype="float32", seed=0):
         generator = paddle.Generator().manual_seed(seed)
-        init_image = load_image(f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint/input_bench_image.png")
-        mask_image = load_image(f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint/input_bench_mask.png")
+        init_image = load_image(
+            "https://huggingface.co/datasets/diffusers/test-arrays/resolve/main/stable_diffusion_inpaint/input_bench_image.png"
+        )
+        mask_image = load_image(
+            "https://huggingface.co/datasets/diffusers/test-arrays/resolve/main/stable_diffusion_inpaint/input_bench_mask.png"
+        )
         inputs = {
             "prompt": "A red cat sitting on a park bench",
             "image": init_image,
@@ -496,56 +415,47 @@ class StableDiffusionInpaintLegacyPipelineNightlyTests(unittest.TestCase):
 
     def test_inpaint_pndm(self):
         sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
+        sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
-
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-
-        expected_image = load_numpy(
-            f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint_legacy/stable_diffusion_1_5_pndm.npy"
-        )
-        max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 1e-3
+        expected_image = np.array([[0.7330009, 0.80003107, 0.8268216], [0.73606366, 0.801595, 0.8470554]])
+        max_diff = np.abs(expected_image - image[0][0:2]).max()
+        assert max_diff < 0.001
 
     def test_inpaint_ddim(self):
         sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = DDIMScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
-
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-
         expected_image = load_numpy(
-            f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint_legacy/stable_diffusion_1_5_ddim.npy"
+            "https://huggingface.co/datasets/diffusers/test-arrays/resolve/main/stable_diffusion_inpaint_legacy/stable_diffusion_1_5_ddim.npy"
         )
-        max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 1e-3
+        expected_image = np.array([[0.7290994, 0.794852, 0.82096446], [0.7330909, 0.79727536, 0.8420528]])
+        max_diff = np.abs(expected_image - image[0][0:2]).max()
+        assert max_diff < 0.001
 
     def test_inpaint_lms(self):
         sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
-
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-
-        expected_image = load_numpy(
-            f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint_legacy/stable_diffusion_1_5_lms.npy"
-        )
-        max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 1e-3
+        expected_image = np.array([[0.74595624, 0.81757987, 0.84589916], [0.74728143, 0.81736475, 0.86543]])
+        max_diff = np.abs(expected_image - image[0][0:2]).max()
+        assert max_diff < 0.001
 
     def test_inpaint_dpm(self):
         sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
-
         inputs = self.get_inputs()
         inputs["num_inference_steps"] = 30
         image = sd_pipe(**inputs).images[0]
-
-        expected_image = load_numpy(
-            f"{TEST_DOWNLOAD_SERVER}/stable_diffusion_inpaint_legacy/stable_diffusion_1_5_dpm_multi.npy"
-        )
-        max_diff = np.abs(expected_image - image).max()
-        assert max_diff < 1e-3
+        expected_image = np.array([[0.7310472, 0.7970823, 0.8231524], [0.7348697, 0.799358, 0.8439586]])
+        max_diff = np.abs(expected_image - image[0][0:2]).max()
+        assert max_diff < 0.001
