@@ -1,5 +1,5 @@
-# coding=utf-8
-# Copyright 2022 HuggingFace Inc.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,25 +20,27 @@ import unittest
 import numpy as np
 import paddle
 from PIL import Image
-from test_pipelines_common import PipelineTesterMixin
-
-from paddlenlp.transformers import (
-    CLIPFeatureExtractor,
-    CLIPTextConfig,
-    CLIPTextModel,
-    CLIPTokenizer,
+from ppdiffusers_test.pipeline_params import (
+    TEXT_GUIDED_IMAGE_INPAINTING_BATCH_PARAMS,
+    TEXT_GUIDED_IMAGE_INPAINTING_PARAMS,
 )
+from ppdiffusers_test.test_pipelines_common import PipelineTesterMixin
+
+from paddlenlp.transformers import CLIPTextConfig, CLIPTextModel, CLIPTokenizer
 from ppdiffusers import (
     AutoencoderKL,
     PNDMScheduler,
     StableDiffusionInpaintPipeline,
     UNet2DConditionModel,
 )
-from ppdiffusers.utils import floats_tensor, load_image, load_numpy, slow
+from ppdiffusers.utils import floats_tensor, load_image
+from ppdiffusers.utils.testing_utils import require_paddle_gpu, slow
 
 
 class StableDiffusion2InpaintPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
     pipeline_class = StableDiffusionInpaintPipeline
+    params = TEXT_GUIDED_IMAGE_INPAINTING_PARAMS
+    batch_params = TEXT_GUIDED_IMAGE_INPAINTING_BATCH_PARAMS
 
     def get_dummy_components(self):
         paddle.seed(0)
@@ -51,8 +53,7 @@ class StableDiffusion2InpaintPipelineFastTests(PipelineTesterMixin, unittest.Tes
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
             cross_attention_dim=32,
-            # SD2-specific config below
-            attention_head_dim=(2, 4, 8, 8),
+            attention_head_dim=(2, 4),
             use_linear_projection=True,
         )
         scheduler = PNDMScheduler(skip_prk_steps=True)
@@ -64,24 +65,24 @@ class StableDiffusion2InpaintPipelineFastTests(PipelineTesterMixin, unittest.Tes
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
             latent_channels=4,
+            sample_size=128,
         )
-
         paddle.seed(0)
-        text_encoder_config = dict(
-            text_embed_dim=32,
-            text_heads=4,
-            text_layers=5,
+        text_encoder_config = CLIPTextConfig(
+            bos_token_id=0,
+            eos_token_id=2,
+            hidden_size=32,
+            intermediate_size=37,
+            layer_norm_eps=1e-05,
+            num_attention_heads=4,
+            num_hidden_layers=5,
+            pad_token_id=1,
             vocab_size=1000,
-            # SD2-specific config below
-            text_hidden_act="gelu",
+            hidden_act="gelu",
             projection_dim=512,
         )
-        text_encoder_config = CLIPTextConfig.from_dict(text_encoder_config)
-        text_encoder = CLIPTextModel(text_encoder_config)
-        text_encoder.eval()
+        text_encoder = CLIPTextModel(text_encoder_config).eval()
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-        feature_extractor = CLIPFeatureExtractor(crop_size=32)
-
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -89,17 +90,17 @@ class StableDiffusion2InpaintPipelineFastTests(PipelineTesterMixin, unittest.Tes
             "text_encoder": text_encoder,
             "tokenizer": tokenizer,
             "safety_checker": None,
-            "feature_extractor": feature_extractor,
+            "feature_extractor": None,
         }
         return components
 
     def get_dummy_inputs(self, seed=0):
-        # TODO: use tensor inputs instead of PIL, this is here just to leave the old expected_slices untouched
         image = floats_tensor((1, 3, 32, 32), rng=random.Random(seed))
-        image = image.cpu().transpose([0, 2, 3, 1])[0]
+        image = image.cpu().transpose(perm=[0, 2, 3, 1])[0]
         init_image = Image.fromarray(np.uint8(image)).convert("RGB").resize((64, 64))
         mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((64, 64))
         generator = paddle.Generator().manual_seed(seed)
+
         inputs = {
             "prompt": "A painting of a squirrel eating a burger",
             "image": init_image,
@@ -115,60 +116,78 @@ class StableDiffusion2InpaintPipelineFastTests(PipelineTesterMixin, unittest.Tes
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionInpaintPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
-
         inputs = self.get_dummy_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
-
         assert image.shape == (1, 64, 64, 3)
         expected_slice = np.array(
-            [
-                0.4040220379829407,
-                0.4376600682735443,
-                0.41725587844848633,
-                0.4457714259624481,
-                0.40201932191848755,
-                0.5004723072052002,
-                0.39662542939186096,
-                0.2882365584373474,
-                0.4356308579444885,
-            ]
+            [0.4439444, 0.42713565, 0.3371228, 0.45478657, 0.39641544, 0.48424238, 0.40045372, 0.3282157, 0.41219836]
         )
-
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
 
 @slow
+@require_paddle_gpu
 class StableDiffusionInpaintPipelineIntegrationTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
 
     def test_stable_diffusion_inpaint_pipeline(self):
-        init_image = load_image("https://paddlenlp.bj.bcebos.com/models/community/CompVis/data/init_image_sd2.png")
-        mask_image = load_image("https://paddlenlp.bj.bcebos.com/models/community/CompVis/data/mask_sd2.png")
-        expected_image = load_numpy(
-            "https://paddlenlp.bj.bcebos.com/models/community/CompVis/data/yellow_cat_sitting_on_a_park_bench_sd2.npy"
+        init_image = load_image(
+            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/sd2-inpaint/init_image.png"
         )
-
+        mask_image = load_image(
+            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/sd2-inpaint/mask.png"
+        )
+        # invalid expected_image
+        # expected_image = load_numpy(
+        #     'https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/sd2-inpaint/yellow_cat_sitting_on_a_park_bench.npy'
+        #     )
         model_id = "stabilityai/stable-diffusion-2-inpainting"
         pipe = StableDiffusionInpaintPipeline.from_pretrained(model_id, safety_checker=None)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
-
         prompt = "Face of a yellow cat, high resolution, sitting on a park bench"
-
         generator = paddle.Generator().manual_seed(0)
-        output = pipe(
-            prompt=prompt,
-            image=init_image,
-            mask_image=mask_image,
-            generator=generator,
-            output_type="np",
-        )
+        output = pipe(prompt=prompt, image=init_image, mask_image=mask_image, generator=generator, output_type="np")
         image = output.images[0]
-
         assert image.shape == (512, 512, 3)
-        assert np.abs(expected_image - image).max() < 1e-3
+        image = image[-3:, -3:, -1]
+        expected_image = [
+            [[0.47980508], [0.49545538], [0.501472]],
+            [[0.36860222], [0.5465546], [0.54940426]],
+            [[0.44748512], [0.45160148], [0.48374733]],
+        ]
+        assert np.abs(expected_image - image).max() < 0.001
+
+    def test_stable_diffusion_inpaint_pipeline_fp16(self):
+        init_image = load_image(
+            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/sd2-inpaint/init_image.png"
+        )
+        mask_image = load_image(
+            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/sd2-inpaint/mask.png"
+        )
+        # invalid expected_image
+        # expected_image = load_numpy(
+        #     'https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/sd2-inpaint/yellow_cat_sitting_on_a_park_bench_fp16.npy'
+        #     )
+        model_id = "stabilityai/stable-diffusion-2-inpainting"
+        pipe = StableDiffusionInpaintPipeline.from_pretrained(
+            model_id, paddle_dtype=paddle.float16, safety_checker=None
+        )
+        pipe.set_progress_bar_config(disable=None)
+        pipe.enable_attention_slicing()
+        prompt = "Face of a yellow cat, high resolution, sitting on a park bench"
+        generator = paddle.Generator().manual_seed(0)
+        output = pipe(prompt=prompt, image=init_image, mask_image=mask_image, generator=generator, output_type="np")
+        image = output.images[0]
+        assert image.shape == (512, 512, 3)
+        image = image[-3:, -3:, -1]
+        expected_image = [
+            [[0.47851562], [0.4951172], [0.50097656]],
+            [[0.36865234], [0.546875], [0.5493164]],
+            [[0.44726562], [0.45141602], [0.48388672]],
+        ]
+        assert np.abs(expected_image - image).max() < 0.5
