@@ -1,5 +1,5 @@
-# coding=utf-8
-# Copyright 2022 HuggingFace Inc.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 
 import gc
 import random
+import tempfile
 import unittest
 
 import numpy as np
@@ -31,12 +32,12 @@ from ppdiffusers import (
 from ppdiffusers.pipelines.stable_diffusion_safe import (
     StableDiffusionPipelineSafe as StableDiffusionPipeline,
 )
-from ppdiffusers.utils import floats_tensor, slow
+from ppdiffusers.utils import floats_tensor, nightly
+from ppdiffusers.utils.testing_utils import require_paddle_gpu
 
 
 class SafeDiffusionPipelineFastTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
@@ -45,8 +46,7 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
     def dummy_image(self):
         batch_size = 1
         num_channels = 3
-        sizes = (32, 32)
-
+        sizes = 32, 32
         image = floats_tensor((batch_size, num_channels) + sizes, rng=random.Random(0))
         return image
 
@@ -56,7 +56,7 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
         model = UNet2DConditionModel(
             block_out_channels=(32, 64),
             layers_per_block=2,
-            sample_size=64,
+            sample_size=32,
             in_channels=4,
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
@@ -81,25 +81,28 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
     @property
     def dummy_text_encoder(self):
         paddle.seed(0)
-        config = dict(
-            text_embed_dim=32,
-            text_heads=4,
-            text_layers=5,
+        config = CLIPTextConfig(
+            bos_token_id=0,
+            eos_token_id=2,
+            hidden_size=32,
+            intermediate_size=37,
+            layer_norm_eps=1e-05,
+            num_attention_heads=4,
+            num_hidden_layers=5,
+            pad_token_id=1,
             vocab_size=1000,
         )
-        config = CLIPTextConfig.from_dict(config)
-        model = CLIPTextModel(config)
-        model.eval()
-        return model
+        return CLIPTextModel(config).eval()
 
     @property
     def dummy_extractor(self):
         def extract(*args, **kwargs):
             class Out:
                 def __init__(self):
-                    self.pixel_values = paddle.ones([0])
+                    self.pixel_values = paddle.ones(shape=[0])
 
-                def to(self, *args, **kwargs):
+                def to(self, device):
+                    self.pixel_values
                     return self
 
             return Out()
@@ -115,12 +118,9 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
             clip_sample=False,
             set_alpha_to_one=False,
         )
-
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-
-        # make sure here that pndm scheduler skips prk
         sd_pipe = StableDiffusionPipeline(
             unet=unet,
             scheduler=scheduler,
@@ -131,13 +131,10 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
             feature_extractor=self.dummy_extractor,
         )
         sd_pipe.set_progress_bar_config(disable=None)
-
         prompt = "A painting of a squirrel eating a burger"
-
         generator = paddle.Generator().manual_seed(0)
         output = sd_pipe([prompt], generator=generator, guidance_scale=6.0, num_inference_steps=2, output_type="np")
         image = output.images
-
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = sd_pipe(
             [prompt],
@@ -147,26 +144,14 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
             output_type="np",
             return_dict=False,
         )[0]
-
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
-
-        assert image.shape == (1, 128, 128, 3)
+        assert image.shape == (1, 64, 64, 3)
         expected_slice = np.array(
-            [
-                0.5384523868560791,
-                0.7189769744873047,
-                0.3174622058868408,
-                0.4472818076610565,
-                0.5456932187080383,
-                0.35453569889068604,
-                0.39105305075645447,
-                0.4643339216709137,
-                0.44654926657676697,
-            ]
+            [0.29159135, 0.20539099, 0.29126638, 0.19384947, 0.24368581, 0.455625, 0.12645328, 0.14380595, 0.35203338]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_pndm(self):
         unet = self.dummy_cond_unet
@@ -174,8 +159,6 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
         tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-
-        # make sure here that pndm scheduler skips prk
         sd_pipe = StableDiffusionPipeline(
             unet=unet,
             scheduler=scheduler,
@@ -186,13 +169,10 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
             feature_extractor=self.dummy_extractor,
         )
         sd_pipe.set_progress_bar_config(disable=None)
-
         prompt = "A painting of a squirrel eating a burger"
         generator = paddle.Generator().manual_seed(0)
         output = sd_pipe([prompt], generator=generator, guidance_scale=6.0, num_inference_steps=2, output_type="np")
-
         image = output.images
-
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = sd_pipe(
             [prompt],
@@ -202,53 +182,70 @@ class SafeDiffusionPipelineFastTests(unittest.TestCase):
             output_type="np",
             return_dict=False,
         )[0]
-
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
-
-        assert image.shape == (1, 128, 128, 3)
+        assert image.shape == (1, 64, 64, 3)
         expected_slice = np.array(
             [
-                0.6677020788192749,
-                0.8690440058708191,
-                0.3959217965602875,
-                0.41445955634117126,
-                0.4883394241333008,
-                0.3246898651123047,
-                0.35466185212135315,
-                0.43880611658096313,
-                0.48951300978660583,
+                0.18087387,
+                0.21568692,
+                0.29702544,
+                0.21842742,
+                0.24647826,
+                0.46706018,
+                0.17106229,
+                0.14040047,
+                0.33457834,
             ]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
 
-    # def test_stable_diffusion_no_safety_checker(self):
-    #     pipe = StableDiffusionPipeline.from_pretrained(
-    #         "hf-internal-testing/tiny-stable-diffusion-lms-pipe",
-    #         safety_checker=None)
-    #     assert isinstance(pipe, StableDiffusionPipeline)
-    #     assert isinstance(pipe.scheduler, LMSDiscreteScheduler)
-    #     assert pipe.safety_checker is None
+    def test_stable_diffusion_no_safety_checker(self):
+        pipe = StableDiffusionPipeline.from_pretrained(
+            "hf-internal-testing/tiny-stable-diffusion-lms-pipe", safety_checker=None
+        )
+        assert isinstance(pipe, StableDiffusionPipeline)
+        assert isinstance(pipe.scheduler, LMSDiscreteScheduler)
+        assert pipe.safety_checker is None
+        image = pipe("example prompt", num_inference_steps=2).images[0]
+        assert image is not None
+        with tempfile.TemporaryDirectory() as tmpdirname:
+            pipe.save_pretrained(tmpdirname)
+            pipe = StableDiffusionPipeline.from_pretrained(tmpdirname, from_diffusers=False)
+        assert pipe.safety_checker is None
+        image = pipe("example prompt", num_inference_steps=2).images[0]
+        assert image is not None
 
-    #     image = pipe("example prompt", num_inference_steps=2).images[0]
-    #     assert image is not None
-
-    #     # check that there's no error when saving a pipeline with one of the models being None
-    #     with tempfile.TemporaryDirectory() as tmpdirname:
-    #         pipe.save_pretrained(tmpdirname)
-    #         pipe = StableDiffusionPipeline.from_pretrained(tmpdirname)
-
-    #     # sanity check that the pipeline still works
-    #     assert pipe.safety_checker is None
-    #     image = pipe("example prompt", num_inference_steps=2).images[0]
-    #     assert image is not None
+    def test_stable_diffusion_fp16(self):
+        """Test that stable diffusion works with fp16"""
+        unet = self.dummy_cond_unet
+        scheduler = PNDMScheduler(skip_prk_steps=True)
+        vae = self.dummy_vae
+        bert = self.dummy_text_encoder
+        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        unet = unet.to(dtype=paddle.float16)
+        vae = vae.to(dtype=paddle.float16)
+        bert = bert.to(dtype=paddle.float16)
+        sd_pipe = StableDiffusionPipeline(
+            unet=unet,
+            scheduler=scheduler,
+            vae=vae,
+            text_encoder=bert,
+            tokenizer=tokenizer,
+            safety_checker=None,
+            feature_extractor=self.dummy_extractor,
+        )
+        sd_pipe.set_progress_bar_config(disable=None)
+        prompt = "A painting of a squirrel eating a burger"
+        image = sd_pipe([prompt], num_inference_steps=2, output_type="np").images
+        assert image.shape == (1, 64, 64, 3)
 
 
-@slow
+@nightly
+@require_paddle_gpu
 class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
@@ -257,18 +254,10 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
         sd_pipe = StableDiffusionPipeline.from_pretrained("runwayml/stable-diffusion-v1-5", safety_checker=None)
         sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
-
-        prompt = (
-            "portrait of girl with smokey eyes makeup in abandoned hotel, grange clothes, redshift, wide high angle"
-            " coloured polaroid photograph with flash, kodak film, hyper real, stunning moody cinematography, with"
-            " anamorphic lenses, by maripol, fallen angels by wong kar - wai, style of suspiria and neon demon and"
-            " children from bahnhof zoo, detailed "
-        )
+        prompt = "portrait of girl with smokey eyes makeup in abandoned hotel, grange clothes, redshift, wide high angle coloured polaroid photograph with flash, kodak film, hyper real, stunning moody cinematography, with anamorphic lenses, by maripol, fallen angels by wong kar - wai, style of suspiria and neon demon and children from bahnhof zoo, detailed "
         seed = 4003660346
         guidance_scale = 7
-
-        # without safety guidance (sld_guidance_scale = 0)
-        generator = paddle.Generator().manual_seed(seed)
+        generator = paddle.Generator().manual_seed(seed=seed)
         output = sd_pipe(
             [prompt],
             generator=generator,
@@ -279,16 +268,12 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
             height=512,
             sld_guidance_scale=0,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         expected_slice = [0.2278, 0.2231, 0.2249, 0.2333, 0.2303, 0.1885, 0.2273, 0.2144, 0.2176]
-
         assert image.shape == (1, 512, 512, 3)
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-
-        # without safety guidance (strong configuration)
-        generator = paddle.Generator().manual_seed(seed)
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        generator = paddle.Generator().manual_seed(seed=seed)
         output = sd_pipe(
             [prompt],
             generator=generator,
@@ -303,24 +288,20 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
             sld_momentum_scale=0.5,
             sld_mom_beta=0.7,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         expected_slice = [0.2383, 0.2276, 0.236, 0.2192, 0.2186, 0.2053, 0.1971, 0.1901, 0.1719]
-
         assert image.shape == (1, 512, 512, 3)
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_nudity_safe_stable_diffusion(self):
         sd_pipe = StableDiffusionPipeline.from_pretrained("runwayml/stable-diffusion-v1-5", safety_checker=None)
         sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
-
         prompt = "padme amidala taking a bath artwork, safe for work, no nudity"
         seed = 2734971755
         guidance_scale = 7
-
-        generator = paddle.Generator().manual_seed(seed)
+        generator = paddle.Generator().manual_seed(seed=seed)
         output = sd_pipe(
             [prompt],
             generator=generator,
@@ -331,15 +312,12 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
             height=512,
             sld_guidance_scale=0,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         expected_slice = [0.3502, 0.3622, 0.3396, 0.3642, 0.3478, 0.3318, 0.35, 0.3348, 0.3297]
-
         assert image.shape == (1, 512, 512, 3)
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-
-        generator = paddle.Generator().manual_seed(seed)
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        generator = paddle.Generator().manual_seed(seed=seed)
         output = sd_pipe(
             [prompt],
             generator=generator,
@@ -354,26 +332,19 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
             sld_momentum_scale=0.5,
             sld_mom_beta=0.7,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         expected_slice = [0.5531, 0.5206, 0.4895, 0.5156, 0.5182, 0.4751, 0.4802, 0.4803, 0.4443]
-
         assert image.shape == (1, 512, 512, 3)
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_nudity_safetychecker_safe_stable_diffusion(self):
         sd_pipe = StableDiffusionPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
         sd_pipe.set_progress_bar_config(disable=None)
-
-        prompt = (
-            "the four horsewomen of the apocalypse, painting by tom of finland, gaston bussiere, craig mullins, j. c."
-            " leyendecker"
-        )
+        prompt = "the four horsewomen of the apocalypse, painting by tom of finland, gaston bussiere, craig mullins, j. c. leyendecker"
         seed = 1044355234
         guidance_scale = 12
-
-        generator = paddle.Generator().manual_seed(seed)
+        generator = paddle.Generator().manual_seed(seed=seed)
         output = sd_pipe(
             [prompt],
             generator=generator,
@@ -384,15 +355,12 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
             height=512,
             sld_guidance_scale=0,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         expected_slice = np.array([0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0])
-
         assert image.shape == (1, 512, 512, 3)
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-7
-
-        generator = paddle.Generator().manual_seed(seed)
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-07
+        generator = paddle.Generator().manual_seed(seed=seed)
         output = sd_pipe(
             [prompt],
             generator=generator,
@@ -407,9 +375,8 @@ class SafeDiffusionPipelineIntegrationTests(unittest.TestCase):
             sld_momentum_scale=0.5,
             sld_mom_beta=0.7,
         )
-
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         expected_slice = np.array([0.5818, 0.6285, 0.6835, 0.6019, 0.625, 0.6754, 0.6096, 0.6334, 0.6561])
         assert image.shape == (1, 512, 512, 3)
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
