@@ -1,5 +1,5 @@
-# coding=utf-8
-# Copyright 2022 HuggingFace Inc.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,11 +30,11 @@ from ppdiffusers.pipelines.vq_diffusion.pipeline_vq_diffusion import (
     LearnedClassifierFreeSamplingEmbeddings,
 )
 from ppdiffusers.utils import load_numpy, slow
+from ppdiffusers.utils.testing_utils import require_paddle_gpu
 
 
 class VQDiffusionPipelineFastTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
@@ -74,24 +74,24 @@ class VQDiffusionPipelineFastTests(unittest.TestCase):
     @property
     def dummy_text_encoder(self):
         paddle.seed(0)
-        config = dict(
-            text_embed_dim=self.text_embedder_hidden_size,
-            text_heads=4,
-            text_layers=5,
+        config = CLIPTextConfig(
+            bos_token_id=0,
+            eos_token_id=2,
+            hidden_size=self.text_embedder_hidden_size,
+            intermediate_size=37,
+            layer_norm_eps=1e-05,
+            num_attention_heads=4,
+            num_hidden_layers=5,
+            pad_token_id=1,
             vocab_size=1000,
         )
-        config = CLIPTextConfig.from_dict(config)
-        model = CLIPTextModel(config)
-        model.eval()
-        return model
+        return CLIPTextModel(config).eval()
 
     @property
     def dummy_transformer(self):
         paddle.seed(0)
-
         height = 12
         width = 12
-
         model_kwargs = {
             "attention_bias": True,
             "cross_attention_dim": 32,
@@ -103,19 +103,16 @@ class VQDiffusionPipelineFastTests(unittest.TestCase):
             "sample_size": width,
             "activation_fn": "geglu-approximate",
         }
-
         model = Transformer2DModel(**model_kwargs)
         return model
 
     def test_vq_diffusion(self):
-
         vqvae = self.dummy_vqvae
         text_encoder = self.dummy_text_encoder
         tokenizer = self.dummy_tokenizer
         transformer = self.dummy_transformer
         scheduler = VQDiffusionScheduler(self.num_embed)
         learned_classifier_free_sampling_embeddings = LearnedClassifierFreeSamplingEmbeddings(learnable=False)
-
         pipe = VQDiffusionPipeline(
             vqvae=vqvae,
             text_encoder=text_encoder,
@@ -125,41 +122,25 @@ class VQDiffusionPipelineFastTests(unittest.TestCase):
             learned_classifier_free_sampling_embeddings=learned_classifier_free_sampling_embeddings,
         )
         pipe.set_progress_bar_config(disable=None)
-
         prompt = "teddy bear playing in the pool"
-
         generator = paddle.Generator().manual_seed(0)
         output = pipe([prompt], generator=generator, num_inference_steps=2, output_type="np")
         image = output.images
-
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = pipe(
             [prompt], generator=generator, output_type="np", return_dict=False, num_inference_steps=2
         )[0]
-
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
-
         assert image.shape == (1, 24, 24, 3)
-
         expected_slice = np.array(
-            [
-                0.6901105642318726,
-                0.5934056639671326,
-                0.5921000838279724,
-                0.4860895872116089,
-                0.6917713284492493,
-                0.5599623918533325,
-                0.6187697649002075,
-                0.728931188583374,
-                0.6061633229255676,
-            ]
+            [0.828682, 0.9523265, 0.9386728, 1.0, 0.670735, 0.69808894, 0.57591987, 0.5695971, 0.6580568]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 1e-2
+        # breakpoint()
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
 
     def test_vq_diffusion_classifier_free_sampling(self):
-
         vqvae = self.dummy_vqvae
         text_encoder = self.dummy_text_encoder
         tokenizer = self.dummy_tokenizer
@@ -168,7 +149,6 @@ class VQDiffusionPipelineFastTests(unittest.TestCase):
         learned_classifier_free_sampling_embeddings = LearnedClassifierFreeSamplingEmbeddings(
             learnable=True, hidden_size=self.text_embedder_hidden_size, length=tokenizer.model_max_length
         )
-
         pipe = VQDiffusionPipeline(
             vqvae=vqvae,
             text_encoder=text_encoder,
@@ -178,65 +158,44 @@ class VQDiffusionPipelineFastTests(unittest.TestCase):
             learned_classifier_free_sampling_embeddings=learned_classifier_free_sampling_embeddings,
         )
         pipe.set_progress_bar_config(disable=None)
-
         prompt = "teddy bear playing in the pool"
-
         generator = paddle.Generator().manual_seed(0)
         output = pipe([prompt], generator=generator, num_inference_steps=2, output_type="np")
         image = output.images
-
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = pipe(
             [prompt], generator=generator, output_type="np", return_dict=False, num_inference_steps=2
         )[0]
-
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
-
         assert image.shape == (1, 24, 24, 3)
-
+        # breakpoint()
         expected_slice = np.array(
-            [
-                0.6959998607635498,
-                0.7165096998214722,
-                0.739770770072937,
-                0.7538110017776489,
-                0.8786328434944153,
-                0.6491624712944031,
-                0.6340304017066956,
-                0.7169196605682373,
-                0.7034797668457031,
-            ]
+            [0.51841056, 0.8037737, 0.71010727, 0.8259821, 0.6837207, 0.53903896, 0.80566585, 0.79730004, 0.7192132]
         )
-        assert np.abs(image_slice.flatten() - expected_slice).max() < 1e-2
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 1e-2
+        assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
 
 
 @slow
+@require_paddle_gpu
 class VQDiffusionPipelineIntegrationTests(unittest.TestCase):
     def tearDown(self):
-        # clean up the VRAM after each test
         super().tearDown()
         gc.collect()
         paddle.device.cuda.empty_cache()
 
     def test_vq_diffusion_classifier_free_sampling(self):
         expected_image = load_numpy(
-            "https://paddlenlp.bj.bcebos.com/models/community/CompVis/data/teddy_bear_pool_classifier_free_sampling.npy"
+            "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/vq_diffusion/teddy_bear_pool_classifier_free_sampling.npy"
         )
-
         pipeline = VQDiffusionPipeline.from_pretrained("microsoft/vq-diffusion-ithq")
+        pipeline = pipeline
         pipeline.set_progress_bar_config(disable=None)
-
         generator = paddle.Generator().manual_seed(0)
         output = pipeline(
-            "teddy bear playing in the pool",
-            num_images_per_prompt=1,
-            generator=generator,
-            output_type="np",
+            "teddy bear playing in the pool", num_images_per_prompt=1, generator=generator, output_type="np"
         )
-
         image = output.images[0]
-
         assert image.shape == (256, 256, 3)
-        assert np.abs(expected_image - image).max() < 1e-2
+        assert np.abs(expected_image - image).max() < 0.01
