@@ -1,5 +1,5 @@
-# coding=utf-8
-# Copyright 2022 HuggingFace Inc.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -26,7 +26,6 @@ from ppdiffusers import (
     logging,
 )
 from ppdiffusers.configuration_utils import ConfigMixin, register_to_config
-from ppdiffusers.utils import deprecate
 from ppdiffusers.utils.testing_utils import CaptureLogger
 
 
@@ -34,14 +33,7 @@ class SampleObject(ConfigMixin):
     config_name = "config.json"
 
     @register_to_config
-    def __init__(
-        self,
-        a=2,
-        b=5,
-        c=(2, 5),
-        d="for diffusion",
-        e=[1, 3],
-    ):
+    def __init__(self, a=2, b=5, c=(2, 5), d="for diffusion", e=[1, 3]):
         pass
 
 
@@ -49,14 +41,7 @@ class SampleObject2(ConfigMixin):
     config_name = "config.json"
 
     @register_to_config
-    def __init__(
-        self,
-        a=2,
-        b=5,
-        c=(2, 5),
-        d="for diffusion",
-        f=[1, 3],
-    ):
+    def __init__(self, a=2, b=5, c=(2, 5), d="for diffusion", f=[1, 3]):
         pass
 
 
@@ -64,15 +49,7 @@ class SampleObject3(ConfigMixin):
     config_name = "config.json"
 
     @register_to_config
-    def __init__(
-        self,
-        a=2,
-        b=5,
-        c=(2, 5),
-        d="for diffusion",
-        e=[1, 3],
-        f=[1, 3],
-    ):
+    def __init__(self, a=2, b=5, c=(2, 5), d="for diffusion", e=[1, 3], f=[1, 3]):
         pass
 
 
@@ -89,8 +66,6 @@ class ConfigTester(unittest.TestCase):
         assert config["c"] == (2, 5)
         assert config["d"] == "for diffusion"
         assert config["e"] == [1, 3]
-
-        # init ignore private arguments
         obj = SampleObject(_name_or_path="lalala")
         config = obj.config
         assert config["a"] == 2
@@ -98,8 +73,6 @@ class ConfigTester(unittest.TestCase):
         assert config["c"] == (2, 5)
         assert config["d"] == "for diffusion"
         assert config["e"] == [1, 3]
-
-        # can override default
         obj = SampleObject(c=6)
         config = obj.config
         assert config["a"] == 2
@@ -107,8 +80,6 @@ class ConfigTester(unittest.TestCase):
         assert config["c"] == 6
         assert config["d"] == "for diffusion"
         assert config["e"] == [1, 3]
-
-        # can use positional arguments.
         obj = SampleObject(1, c=6)
         config = obj.config
         assert config["a"] == 1
@@ -120,77 +91,59 @@ class ConfigTester(unittest.TestCase):
     def test_save_load(self):
         obj = SampleObject()
         config = obj.config
-
         assert config["a"] == 2
         assert config["b"] == 5
         assert config["c"] == (2, 5)
         assert config["d"] == "for diffusion"
         assert config["e"] == [1, 3]
-
         with tempfile.TemporaryDirectory() as tmpdirname:
             obj.save_config(tmpdirname)
             new_obj = SampleObject.from_config(SampleObject.load_config(tmpdirname))
             new_config = new_obj.config
-
-        # unfreeze configs
         config = dict(config)
         new_config = dict(new_config)
-
-        assert config.pop("c") == (2, 5)  # instantiated as tuple
-        assert new_config.pop("c") == [2, 5]  # saved & loaded as list because of json
+        assert config.pop("c") == (2, 5)
+        assert new_config.pop("c") == [2, 5]
         assert config == new_config
 
     def test_load_ddim_from_pndm(self):
         logger = logging.get_logger("ppdiffusers.configuration_utils")
-
         with CaptureLogger(logger) as cap_logger:
             ddim = DDIMScheduler.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="scheduler"
             )
-
         assert ddim.__class__ == DDIMScheduler
-        # no warning should be thrown
         assert cap_logger.out == ""
 
     def test_load_euler_from_pndm(self):
         logger = logging.get_logger("ppdiffusers.configuration_utils")
-
         with CaptureLogger(logger) as cap_logger:
             euler = EulerDiscreteScheduler.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="scheduler"
             )
-
         assert euler.__class__ == EulerDiscreteScheduler
-        # no warning should be thrown
         assert cap_logger.out == ""
 
     def test_load_euler_ancestral_from_pndm(self):
         logger = logging.get_logger("ppdiffusers.configuration_utils")
-
         with CaptureLogger(logger) as cap_logger:
             euler = EulerAncestralDiscreteScheduler.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="scheduler"
             )
-
         assert euler.__class__ == EulerAncestralDiscreteScheduler
-        # no warning should be thrown
         assert cap_logger.out == ""
 
     def test_load_pndm(self):
         logger = logging.get_logger("ppdiffusers.configuration_utils")
-
         with CaptureLogger(logger) as cap_logger:
             pndm = PNDMScheduler.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="scheduler"
             )
-
         assert pndm.__class__ == PNDMScheduler
-        # no warning should be thrown
         assert cap_logger.out == ""
 
     def test_overwrite_config_on_load(self):
         logger = logging.get_logger("ppdiffusers.configuration_utils")
-
         with CaptureLogger(logger) as cap_logger:
             ddpm = DDPMScheduler.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch",
@@ -198,37 +151,20 @@ class ConfigTester(unittest.TestCase):
                 prediction_type="sample",
                 beta_end=8,
             )
-
         with CaptureLogger(logger) as cap_logger_2:
-            ddpm_2 = DDPMScheduler.from_pretrained("google/ddpm-celebahq-256", beta_start=88, subfolder="scheduler")
-
-        with CaptureLogger(logger) as cap_logger:
-            deprecate("remove this case", "0.13.0", "remove")
-            ddpm_3 = DDPMScheduler.from_pretrained(
-                "hf-internal-testing/tiny-stable-diffusion-torch",
-                subfolder="scheduler",
-                predict_epsilon=False,
-                beta_end=8,
-            )
-
+            ddpm_2 = DDPMScheduler.from_pretrained("google/ddpm-celebahq-256", beta_start=88)
         assert ddpm.__class__ == DDPMScheduler
         assert ddpm.config.prediction_type == "sample"
         assert ddpm.config.beta_end == 8
         assert ddpm_2.config.beta_start == 88
-        assert ddpm_3.config.prediction_type == "sample"
-
-        # no warning should be thrown
         assert cap_logger.out == ""
         assert cap_logger_2.out == ""
 
     def test_load_dpmsolver(self):
         logger = logging.get_logger("ppdiffusers.configuration_utils")
-
         with CaptureLogger(logger) as cap_logger:
             dpm = DPMSolverMultistepScheduler.from_pretrained(
                 "hf-internal-testing/tiny-stable-diffusion-torch", subfolder="scheduler"
             )
-
         assert dpm.__class__ == DPMSolverMultistepScheduler
-        # no warning should be thrown
         assert cap_logger.out == ""
